# encoding: utf-8

class BannerImageUploader < CarrierWave::Uploader::Base

  # Include RMagick or MiniMagick support:
  # include CarrierWave::RMagick
  # include CarrierWave::MiniMagick
  include CarrierWave::MiniMagick

  # Choose what kind of storage to use for this uploader:
  storage :file
  # storage :fog

  # Override the directory where uploaded files will be stored.
  # This is a sensible default for uploaders that are meant to be mounted:
  def store_dir
    "uploads/banner_image/#{mounted_as}/#{model.id}"
  end

   # override
  def filename
    @original_filename
  end

  # override
  def original_filename=(filename)
    @original_filename = super(filename)

    if(@original_filename.bytesize > 200)
      original_file_extension = File.extname(@original_filename)

      @original_filename.force_encoding("ascii-8bit")
      @original_filename = @original_filename[0, (200 - original_file_extension.bytesize)]
      @original_filename.encode!("UTF-16BE", "UTF-8", :invalid => :replace, :undef => :replace, :replace => '')
      @original_filename.encode!("UTF-8")

      @original_filename += original_file_extension
    end

    @original_filename
  end

  def fix_exif_rotation 
    manipulate! do |img|
      img.tap(&:auto_orient)
    end
  end
  # Provide a default URL as a default if there hasn't been a file uploaded:
  # def default_url
  #   # For Rails 3.1+ asset pipeline compatibility:
  #   # ActionController::Base.helpers.asset_path("fallback/" + [version_name, "default.png"].compact.join('_'))
  #
  #   "/images/fallback/" + [version_name, "default.png"].compact.join('_')
  # end

  # Process files as they are uploaded:
  # process :scale => [200, 300]
  #
  # def scale(width, height)
  #   # do something
  # end

  # Create different versions of your uploaded files:
   version :thumb do
     process :fix_exif_rotation
     process :resize_to_fit => [400, 400]
   end

   version :mobile do
    process :fix_exif_rotation
    process :resize_to_limit => [1152, 768]
  end

  # Add a white list of extensions which are allowed to be uploaded.
  # For images you might use something like this:
  def extension_white_list
     %w(jpg jpeg gif png bmp)
  end

  # Override the filename of the uploaded files:
  # Avoid using model.id or version_name here, see uploader/store.rb for details.
  # def filename
  #   "something.jpg" if original_filename
  # end



end
